#version 120

uniform sampler2D tex;
uniform samplerCube cubemap;
uniform float cam_height;

varying vec3 fragcoord;

vec4 calc_fog_color(vec4 tex_color)
{
	vec3 lookup = fragcoord;
	if (abs(lookup.x) > abs(lookup.z))
		lookup.z = -lookup.z;
	else
		lookup.x = -lookup.x;

	vec4 sky_color = textureCube(cubemap, lookup);
	vec3 fog_sky_mix = mix(gl_Fog.color.rgb, sky_color.rgb, 0.8);

	return vec4(fog_sky_mix.rgb, tex_color.a);
}

void main()
{
	vec4 tex_color = texture2D(tex, gl_TexCoord[0].xy);

	// XXX fog_factor could be calculated in vertex shader??
	//

	//float fog = (gl_Fog.end - (gl_FogFragCoord /*+ calc_height_fog_coord(cam_height, fragcoord.y)*/)) * gl_Fog.scale;
	//float fog_factor = (gl_Fog.end - gl_FogFragCoord) * gl_Fog.density;
	////float fog_factor = (gl_Fog.end - gl_FogFragCoord) / (gl_Fog.end - gl_Fog.start) * gl_Fog.density;

	float y = fragcoord.y/5.0;
	float fogcoord = max(gl_FogFragCoord, y*y*y);
	float fog_factor = exp2(-gl_Fog.density * fogcoord);
	fog_factor = clamp(fog_factor, 0.0, 0.8); // XXX 0.9 -> always 0.1 fogged
	vec4 fog_color = calc_fog_color(tex_color);

	gl_FragColor = mix(fog_color, tex_color, fog_factor);

}

