#version 120

uniform vec3 wdir;
uniform float wstr;
uniform mat4 camera_matrix;

varying vec3 fragcoord;

vec4 apply_wind_effect(vec4 vertex)
{
	const float MAX_HEIGHT = 70.0;
	const float MULT = 0.2;

	vec4 pos = gl_ModelViewMatrix * vertex;

	// Position based variance
	float a = mod(abs(pos.x), 80.0) / 80.0 * 3.14159265359 * 0.45;
	vec3 dir = vec3(0.0);
	dir.x = cos(a) * wdir.x - sin(a) * wdir.z;
	dir.z = sin(a) * wdir.x + cos(a) * wdir.z;

	float height = pos.y - gl_ModelViewMatrix[3].y;
	float t = clamp(height / MAX_HEIGHT, 0.0, 1.0);
	vec3 wind_ofs = mix(vec3(0.0), dir * wstr * MULT, t);
	
	return vertex + vec4(wind_ofs, 0.0);
}

void main()
{
	vec4 pos = gl_Vertex;

	pos = apply_wind_effect(pos);
	
	gl_Position = gl_ModelViewProjectionMatrix * pos;

	gl_FrontColor = gl_Color;
	gl_TexCoord[0] = gl_MultiTexCoord0;

	fragcoord = vec3(camera_matrix * gl_ModelViewMatrix * gl_Vertex);

	vec4 cam_space_position = gl_ModelViewMatrix * pos;
	gl_FogFragCoord = length(cam_space_position.xyz);
}

